@@ -20,7 +20,7 @@ Just for internal usage and documentation.
 
 =item B<notice()>
 
-=item B<warning()>, B<warn()>
+=item B<warning()>
 
 =item B<error()>, B<err()>
 
@@ -42,7 +42,7 @@ Just for internal usage and documentation.
 
 =item B<is_notice()>
 
-=item B<is_warning()>, B<is_warn()>
+=item B<is_warning()>
 
 =item B<is_error()>, B<is_err()>
 
@@ -80,6 +80,16 @@ want to know who called C<die()>.
 
     $SIG{__DIE__} = sub { $log->trace(emergency => @_) };
 
+By default the backtrace is logged as level C<debug>.
+
+    # would log with the level debug
+    $log->trace('who called who');
+
+If you want to log with another level then you can pass the level
+as first argument:
+
+    $log->trace(info => $message);
+
 =item B<dump()>
 
 If you want to dump something then you can use C<dump()>.
@@ -87,6 +97,11 @@ The default level is C<debug>.
 
     my %hash = (foo => 1, bar => 2);
 
+    $log->dump(\%hash);
+
+If you want to log with another level then you can pass the level
+as first argument:
+
     $log->dump($level => \%hash);
 
 =item B<die()>
@@ -94,32 +109,25 @@ The default level is C<debug>.
 This method logs the message to the output and then call C<Carp::croak()>
 with the level C<emergency> by default.
 
+    $log->die('an emergency error here');
+
+If you want to log with another level, then you can pass the level
+as first argument:
+
     $log->die(fatal => 'an emergency error here');
 
-=item B<log()>
+=item B<warn()>
 
-With this method it's possible to log messages with the log level as
-first argument:
+This method logs the message with the level warning to the output and
+then calls C<Carp::carp()>.
 
-    $log->log(info => 'an info message');
-
-=item B<tagged()>
-
-With this method it's possible to add some tags to a message:
-
-    $log->tagged(
-        level    => "debug",
-        message  => "log this message",
-        karma    => 42,
-        tags     => "security,foo",
-    );
+    $log->warn('a warning here');
 
 =back
 
 =head1 PREREQUISITES
 
     Carp
-    Data::Dumper
 
 =head1 EXPORTS
 
@@ -137,7 +145,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -151,14 +159,13 @@ use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '0.07';
+our $VERSION  = '0.01';
 
 my %LEVELS_BY_ROUTINE = (
     debug     => 'DEBUG',
     info      => 'INFO',
     notice    => 'NOTICE',
     warning   => 'WARNING',
-    warn      => 'WARNING',
     error     => 'ERROR',
     err       => 'ERROR',
     critical  => 'CRITICAL',
@@ -169,9 +176,7 @@ my %LEVELS_BY_ROUTINE = (
     fatal     => 'FATAL',
 );
 
-foreach my $routine (keys %LEVELS_BY_ROUTINE) {
-    my $level = $LEVELS_BY_ROUTINE{$routine};
-
+while ( my ($routine, $level) = each %LEVELS_BY_ROUTINE ) {
     {   # start "no strict 'refs'" block
         no strict 'refs';
 
@@ -183,23 +188,17 @@ foreach my $routine (keys %LEVELS_BY_ROUTINE) {
             use strict 'refs';
             my $self   = shift;
             my $levels = $self->{levels};
-            my $errors = ();
 
             if ( !$levels->{$level} ) {
                 return 1;
             }
 
             foreach my $output ( @{$levels->{$level}} ) {
-                if ( !$output->log($level, @_) ) {
-                    if ( defined $errors ) {
-                        $errors .= '; ' . $output->errstr;
-                    } else {
-                        $errors = $output->errstr;
-                    }
-                }
+                $output->log($level, @_)
+                    or return $self->_raise_error($output->errstr);
             }
 
-            return defined $errors ? $self->_raise_error($errors) : 1;
+            return 1;
         };
 
         # --------------------------------------------------------------
@@ -216,40 +215,12 @@ foreach my $routine (keys %LEVELS_BY_ROUTINE) {
     } # end "no strict 'refs'" block
 }
 
-sub tagged {
-    my $self  = shift;
-    my $tags  = ref($_[0]) eq "HASH" ? shift : {@_};
-    my $level = $tags->{level};
-
-    if (!defined $level) {
-        $level = $tags->{level} = "info";
-    }
-
-    if (!exists $LEVELS_BY_ROUTINE{$level}) {
-        $level = $tags->{level} = "info";
-    }
-
-    local $Log::Handler::CALLER_LEVEL = 1;
-    return $self->$level($tags);
-}
-
-sub log {
-    my $self  = shift;
-    my $level = @_ > 1 ? lc(shift) : 'info';
-    if (!exists $LEVELS_BY_ROUTINE{$level}) {
-        $level = 'info';
-    }
-    local $Log::Handler::CALLER_LEVEL = 1;
-    return $self->$level(@_);
-}
-
 sub trace {
     my $self  = shift;
     my $level = @_ > 1 ? lc(shift) : 'debug';
     if (!exists $LEVELS_BY_ROUTINE{$level}) {
         $level = 'debug';
     }
-    local $Log::Handler::CALLER_LEVEL = 1;
     local $Log::Handler::TRACE = 1;
     return $self->$level(@_);
 }
@@ -260,19 +231,24 @@ sub die {
     if (!exists $LEVELS_BY_ROUTINE{$level}) {
         $level = 'emergency';
     }
-    local $Log::Handler::CALLER_LEVEL = 1;
     my @caller = caller;
     $self->$level(@_, "at line $caller[2]");
     Carp::croak @_;
 };
 
+sub warn {
+    my $self = shift;
+    my @caller = caller;
+    $self->warning(@_, "at line $caller[2]");
+    Carp::carp @_;
+}
+
 sub dump {
     my $self  = shift;
     my $level = @_ > 1 ? lc(shift) : 'debug';
     if (!exists $LEVELS_BY_ROUTINE{$level}) {
         $level = 'debug';
     }
-    local $Log::Handler::CALLER_LEVEL = 1;
     return $self->$level(Dumper(@_));
 }
 
