@@ -7,13 +7,13 @@ Log::Handler::Output::File - Log messages to a file.
     use Log::Handler::Output::File;
 
     my $log = Log::Handler::Output::File->new(
-        filename    => "file.log",
+        filename    => 'file.log',
         filelock    => 1,
         fileopen    => 1,
         reopen      => 1,
-        mode        => "append",
+        mode        => 'append',
         autoflush   => 1,
-        permissions => "0664",
+        permissions => '0664',
         utf8        => 0,
     );
 
@@ -37,24 +37,63 @@ The following options are possible:
 
 With C<filename> you can set a file name as a string or as a array reference.
 If you set a array reference then the parts will be concat with C<catfile> from
-C<File::Spec>.
+C<File::Spec>. It's also possible to set a GLOBREF or a string as an alias for
+STDOUT or STDERR. The default is STDOUT for this option.
 
 Set a file name:
 
-    my $log = Log::Handler::Output::File->new( filename => "file.log"  );
+    my $log = Log::Handler::Output::File->new( filename => 'file.log'  );
 
 Set a array reference:
 
     my $log = Log::Handler::Output::File->new(
 
         # foo/bar/baz.log
-        filename => [ "foo", "bar", "baz.log" ],
+        filename => [ 'foo', 'bar', 'baz.log' ],
 
         # /foo/bar/baz.log
-        filename => [ "", "foo", "bar", "baz.log" ],
+        filename => [ '', 'foo', 'bar', 'baz.log' ],
 
     );
 
+Set a GLOBREF
+
+    open FH, '>', 'file.log' or die $!;
+    my $log = Log::Handler::Output::File->new( filename => \*FH );
+
+Or the same with
+
+    open my $fh, '>', 'file.log' or die $!;
+    my $log = Log::Handler::Output::File->new( filename => $fh );
+
+Set STDOUT or STDERR
+
+    my $log = Log::Handler::Output::File->new( filename => \*STDOUT );
+    # or
+    my $log = Log::Handler::Output::File->new( filename => \*STDERR );
+
+If the option C<filename> is set in a config file and you want to debug to your
+screen then you can set C<*STDOUT> or C<*STDERR> as a string.
+
+    my $log = Log::Handler::Output::File->new( filename => '*STDOUT' );
+    # or
+    my $log = Log::Handler::Output::File->new( filename => '*STDERR' );
+
+That is not possible:
+
+    my $log = Log::Handler::Output::File->new( filename => '*FH' );
+
+Note that if you set a GLOBREF to C<filename> some options will be forced
+(overwritten) and you have to control the handles yourself. The forced options
+are
+
+    fileopen => 1   # don't close
+    filelock => 0   # don't lock
+    reopen   => 0   # and don't reopen
+
+The reason is simple: if you set C<*STDOUT> as filename it would be very bad
+if it would be closed or locked.
+
 =item B<filelock>
 
 Maybe it's desirable to lock the log file by each write operation because a lot
@@ -89,8 +128,8 @@ To write your code independent you should control it:
     my $os_is_win = $^O =~ /win/i ? 0 : 1;
 
     my $log = Log::Handler::Output::File->new(
-       filename => "file.log",
-       mode     => "append",
+       filename => 'file.log',
+       mode     => 'append',
        fileopen => $os_is_win
     );
 
@@ -100,19 +139,20 @@ If you set C<fileopen> to 0 then it implies that C<reopen> has no importance.
 
 There are three possible modes to open a log file.
 
-    append - O_WRONLY | O_APPEND | O_CREAT (default)
-    excl   - O_WRONLY | O_EXCL   | O_CREAT
+    append - O_WRONLY | O_APPEND | O_CREAT
+    excl   - O_WRONLY | O_EXCL   | O_CREAT (default)
     trunc  - O_WRONLY | O_TRUNC  | O_CREAT
 
 C<append> would open the log file in any case and appends the messages at
 the end of the log file.
 
 C<excl> would fail by open the log file if the log file already exists.
+This is the default option because some security reasons.
 
 C<trunc> would truncate the complete log file if it exists. Please take care
 to use this option.
 
-Take a look to the documentation of C<sysopen()> to get more information.
+Take a look to the documentation of C<sysopen()> to get more informations.
 
 =item B<autoflush>
 
@@ -130,7 +170,7 @@ C<0640> is the default permission for this option. That means that the owner
 got read and write permissions and users in the same group got only read
 permissions. All other users got no access.
 
-Take a look to the documentation of C<sysopen()> to get more information.
+Take a look to the documentation of C<sysopen()> to get more informations.
 
 =item B<utf8>
 
@@ -145,23 +185,7 @@ Call C<log()> if you want to log messages to the log file.
 
 Example:
 
-    $log->log(message => "this message goes to the logfile");
-
-=head2 flush()
-
-Call C<flush()> if you want to re-open the log file.
-
-This is useful if you don't want to use option S<"reopen">. As example
-if a rotate mechanism moves the logfile and you want to re-open a new
-one.
-
-=head2 validate()
-
-Validate a configuration.
-
-=head2 reload()
-
-Reload with a new configuration.
+    $log->log(message => 'this message goes to the logfile');
 
 =head2 errstr()
 
@@ -174,9 +198,7 @@ to use it, because the log file will be opened and closed automatically.
 
 =head1 PREREQUISITES
 
-    Carp
     Fcntl
-    File::Spec
     Params::Validate
 
 =head1 EXPORTS
@@ -195,7 +217,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -206,23 +228,63 @@ package Log::Handler::Output::File;
 
 use strict;
 use warnings;
-use Carp;
 use Fcntl qw( :flock O_WRONLY O_APPEND O_TRUNC O_EXCL O_CREAT );
 use File::Spec;
-use Params::Validate qw();
+use Params::Validate;
 
-our $VERSION = "0.07";
-our $ERRSTR  = "";
+our $VERSION = '0.01';
+our $ERRSTR  = '';
 
 sub new {
-    my $class = shift;
-    my $opts  = $class->_validate(@_);
-    my $self  = bless $opts, $class;
+    my $class   = shift;
+    my $options = $class->_validate(@_);
+    my $self    = bless $options, $class;
+    my $fileref = ref($self->{filename});
+
+    # it's possible to set *STDOUT and *STDERR as string
+    # or pass a GLOB as filename
+    if ($fileref eq 'GLOB') {
+        $self->{fh} = $self->{filename};
+    } elsif ($fileref eq 'ARRAY') {
+        $self->{filename} = File::Spec->catfile(@{$self->{filename}});
+    } elsif ($self->{filename} eq '*STDOUT') {
+        $self->{fh} = \*STDOUT;
+    } elsif ($self->{filename} eq '*STDERR') {
+        $self->{fh} = \*STDERR;
+    }
+
+    # if filename is a GLOB, then we force some options and return
+    if (defined $self->{fh}) {
+        $self->{fileopen} = 1; # never call _open() and _close()
+        $self->{reopen}   = 0; # never try to reopen
+        $self->{filelock} = 0; # no, we won't lock
+        if ($self->{autoflush}) {
+            my $oldfh = select $self->{fh};
+            $| = $self->{autoflush};
+            select $oldfh;
+        }
+        if ($self->{utf8}) {
+            binmode $self->{fh}, ':utf8';
+        }
+        return $self;
+    }
+
+    if ($self->{mode} eq 'append') {
+        $self->{mode} = O_WRONLY | O_APPEND | O_CREAT;
+    } elsif ($self->{mode} eq 'excl') {
+        $self->{mode} = O_WRONLY | O_EXCL | O_CREAT;
+    } elsif ($self->{mode} eq 'trunc') {
+        $self->{mode} = O_WRONLY | O_TRUNC | O_CREAT;
+    }
+
+    $self->{permissions} = oct($self->{permissions});
 
     # open the log file permanent
-    if ($self->{fileopen}) {
-        $self->_open
-            or croak $self->errstr;
+    if ($self->{fileopen} == 1) {
+        $self->_open or return undef;
+        if ($self->{reopen}) {
+            $self->{inode} = (stat($self->{filename}))[1];
+        }
     }
 
     return $self;
@@ -239,31 +301,18 @@ sub log {
     }
 
     if ($self->{filelock}) {
-        flock($self->{fh}, LOCK_EX)
-            or return $self->_raise_error("unable to lock logfile $self->{filename}: $!");
+        $self->_lock or return undef;
     }
 
     print {$self->{fh}} $message->{message} or
         return $self->_raise_error("unable to print to logfile: $!");
 
     if ($self->{filelock}) {
-        flock($self->{fh}, LOCK_UN)
-            or return $self->_raise_error("unable to unlock logfile $self->{filename}: $!");
+        $self->_unlock or return undef;
     }
 
     if (!$self->{fileopen}) {
-        $self->close or return undef;
-    }
-
-    return 1;
-}
-
-sub flush {
-    my $self = shift;
-
-    if ($self->{fileopen}) {
-        $self->close or return undef;
-        $self->_open  or return undef;
+        $self->_close or return undef;
     }
 
     return 1;
@@ -271,57 +320,17 @@ sub flush {
 
 sub close {
     my $self = shift;
-
-    if ($self->{fh}) {
-        CORE::close($self->{fh})
-            or return $self->_raise_error("unable to close logfile $self->{filename}: $!");
-        delete $self->{fh};
-    }
-
-    return 1;
+    return $self->_close;
 }
 
-sub validate {
-    my $self = shift;
-    my $opts = ();
-
-    eval { $opts = $self->_validate(@_) };
-
-    if ($@) {
-        return $self->_raise_error($@);
-    }
-
-    return $opts;
-}
-
-sub reload {
-    my $self = shift;
-    my $opts = $self->validate(@_);
-
-    $self->close;
-
-    foreach my $key (keys %$opts) {
-        $self->{$key} = $opts->{$key};
-    }
-
-    if ($self->{fileopen}) {
-        $self->_open
-            or croak $self->errstr;
-    }
-
-    return 1;
-}
-
-sub errstr {
-    return $ERRSTR;
-}
+sub errstr { $ERRSTR }
 
 sub DESTROY {
     my $self = shift;
-
-    if ($self->{fh}) {
-        CORE::close($self->{fh});
-    }
+    CORE::close($self->{fh})
+        if $self->{fh}
+        && !ref($self->{filename})
+        && $self->{filename} !~ /^\*STDOUT\z|^\*STDERR\z/;
 }
 
 #
@@ -341,35 +350,70 @@ sub _open {
     }
 
     if ($self->{utf8}) {
-        binmode $fh, ":utf8";
-    }
-
-    if ($self->{reopen}) {
-        $self->{inode} = (stat($self->{filename}))[1];
+        binmode $fh, ':utf8' if $self->{utf8};
     }
 
     $self->{fh} = $fh;
     return 1;
 }
 
-sub _checkino {
+sub _close {
     my $self = shift;
 
-    if (!-e $self->{filename} || $self->{inode} != (stat($self->{filename}))[1]) {
-        $self->close or return undef;
-        $self->_open or return undef;
+    if ($self->{fh}) {
+        CORE::close($self->{fh})
+            or return $self->_raise_error("unable to close logfile $self->{filename}: $!");
+        delete $self->{fh};
     }
 
     return 1;
 }
 
+sub _checkino {
+    my $self  = shift;
+
+    if (-e $self->{filename}) {
+        my $ino = (stat($self->{filename}))[1];
+        unless ($self->{inode} == $ino) {
+            $self->_close or return undef;
+            $self->_open or return undef;
+            $self->{inode} = $ino;
+        }
+    } else {
+        $self->_close or return undef;
+        $self->_open or return undef;
+        $self->{inode} = (stat($self->{filename}))[1];
+    }
+
+    return 1;
+}
+
+sub _lock {
+    my $self = shift;
+
+    flock($self->{fh}, LOCK_EX)
+        or return $self->_raise_error("unable to lock logfile $self->{filename}: $!");
+
+    return 1;
+}
+
+sub _unlock {
+    my $self = shift;
+
+    flock($self->{fh}, LOCK_UN)
+        or return $self->_raise_error("unable to unlock logfile $self->{filename}: $!");
+
+    return 1;
+}
+
 sub _validate {
     my $class   = shift;
     my $bool_rx = qr/^[10]\z/;
 
-    my %opts = Params::Validate::validate(@_, {
+    my %options = Params::Validate::validate(@_, {
         filename => {
-            type => Params::Validate::SCALAR | Params::Validate::ARRAYREF,
+            type => Params::Validate::SCALAR | Params::Validate::GLOBREF | Params::Validate::ARRAYREF,
+            default => '*STDOUT',
         },
         filelock => {
             type => Params::Validate::SCALAR,
@@ -389,7 +433,7 @@ sub _validate {
         mode => {
             type => Params::Validate::SCALAR,
             regex => qr/^(append|excl|trunc)\z/,
-            default => "append",
+            default => 'excl',
         },
         autoflush => {
             type => Params::Validate::SCALAR,
@@ -399,7 +443,7 @@ sub _validate {
         permissions => {
             type => Params::Validate::SCALAR,
             regex => qr/^[0-7]{3,4}\z/,
-            default => "0640",
+            default => '0640',
         },
         utf8 => {
             type => Params::Validate::SCALAR,
@@ -408,25 +452,12 @@ sub _validate {
         },
     });
 
-    if (ref($opts{filename}) eq "ARRAY") {
-        $opts{filename} = File::Spec->catfile(@{$opts{filename}});
-    }
-
-    if ($opts{mode} eq "append") {
-        $opts{mode} = O_WRONLY | O_APPEND | O_CREAT;
-    } elsif ($opts{mode} eq "excl") {
-        $opts{mode} = O_WRONLY | O_EXCL | O_CREAT;
-    } elsif ($opts{mode} eq "trunc") {
-        $opts{mode} = O_WRONLY | O_TRUNC | O_CREAT;
-    }
-
-    $opts{permissions} = oct($opts{permissions});
-
-    return \%opts;
+    return \%options;
 }
 
 sub _raise_error {
-    $ERRSTR = $_[1];
+    my $self = shift;
+    $ERRSTR = shift;
     return undef;
 }
 
