@@ -8,7 +8,7 @@ Log::Handler::Output::Forward - Forward messages to routines.
 
     my $forwarder = Log::Handler::Output::Forward->new(
         forward_to => sub { },
-        arguments  => [ "foo" ],
+        arguments  => [ 'foo' ],
     );
 
     $forwarder->log(message => $message);
@@ -44,7 +44,7 @@ C<Class::method()>.
 
     my $forwarder = Log::Handler::Output::Forward->new(
         forward_to => \&Class::method,
-        arguments  => [ $self, "foo" ],
+        arguments  => [ $self, 'foo' ],
     );
 
 This would call intern:
@@ -61,15 +61,7 @@ Call C<log()> if you want to forward messages to the subroutines.
 
 Example:
 
-    $forwarder->log("this message will be forwarded to all sub routines");
-
-=head2 validate()
-
-Validate a configuration.
-
-=head2 reload()
-
-Reload with a new configuration.
+    $forwarder->log('this message will be forwarded to all sub routines');
 
 =head2 errstr()
 
@@ -104,7 +96,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -116,10 +108,10 @@ package Log::Handler::Output::Forward;
 use strict;
 use warnings;
 use Carp;
-use Params::Validate qw();
+use Params::Validate;
 
-our $VERSION = "0.03";
-our $ERRSTR  = "";
+our $VERSION = '0.01';
+our $ERRSTR  = '';
 
 sub new {
     my $class   = shift;
@@ -145,38 +137,7 @@ sub log {
     return 1;
 }
 
-sub validate {
-    my $self = shift;
-    my $opts = ();
-
-    eval { $opts = $self->_validate(@_) };
-
-    if ($@) {
-        $ERRSTR = $@;
-        return undef;
-    }
-
-    return $opts;
-}
-
-sub reload {
-    my $self = shift;
-    my $opts = $self->validate(@_);
-
-    if (!$opts) {
-        return undef;
-    }
-
-    foreach my $key (keys %$opts) {
-        $self->{$key} = $opts->{$key};
-    }
-
-    return 1;
-}
-
-sub errstr {
-    return $ERRSTR;
-}
+sub errstr { $ERRSTR }
 
 #
 # private stuff
