@@ -7,9 +7,9 @@ Log::Handler::Output::Socket - Send messages to a socket.
     use Log::Handler::Output::Socket;
 
     my $sock = Log::Handler::Output::Socket->new(
-        peeraddr    => "127.0.0.1",
+        peeraddr    => '127.0.0.1',
         peerport    => 44444,
-        proto       => "tcp",
+        proto       => 'tcp',
         timeout     => 10
     );
 
@@ -43,14 +43,16 @@ The protocol you wish to use. Default is TCP.
 
 =item B<timeout>
 
-The timeout to send message. The default is 5 seconds.
+The timeout to send message. The default is 1.
 
-=item B<persistent> and B<reconnect>
+=item B<persistent>
 
-With this option you can enable or disable a persistent connection and
-re-connect if the connection was lost.
+Enable a persistent connection to the server. The default is 1.
 
-Both options are set to 1 on default.
+=item B<reconnect>
+
+You can enable this if you want to reconnect to the server after the
+connection lost. The default is 1.
 
 =item B<dump>
 
@@ -80,7 +82,7 @@ C<IO::Socket::INET> and don't want use C<peeraddr> and C<peerhost>.
 Example:
 
         connect => {
-            PerrAddr  => "127.0.0.1",
+            PerrAddr  => '127.0.0.1',
             PeerPort  => 44444,
             LocalPort => 44445
         }
@@ -95,7 +97,7 @@ Call C<log()> if you want to send a message over the socket.
 
 Example:
 
-    $sock->log("message");
+    $sock->log('message');
 
 =head2 connect()
 
@@ -105,25 +107,10 @@ Connect to the socket.
 
 Disconnect from socket.
 
-=head2 validate()
-
-Validate a configuration.
-
-=head2 reload()
-
-Reload with a new configuration.
-
 =head2 errstr()
 
 This function returns the last error message.
 
-=head1 PREREQUISITES
-
-    Carp
-    Params::Validate;
-    IO::Socket::INET;
-    Data::Dumper;
-
 =head1 EXPORTS
 
 No exports.
@@ -140,7 +127,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -151,24 +138,21 @@ package Log::Handler::Output::Socket;
 
 use strict;
 use warnings;
-use Carp;
-use Data::Dumper;
+use Params::Validate;
 use IO::Socket::INET;
-use Params::Validate qw();
+use Data::Dumper;
 
-our $VERSION = "0.08";
-our $ERRSTR  = "";
+our $VERSION = '0.01';
+our $ERRSTR  = '';
 
 sub new {
-    my $class = shift;
-    my $opts  = $class->_validate(@_);
-    my $self  = bless $opts, $class;
-
+    my $class   = shift;
+    my $options = $class->_validate(@_);
+    my $self    = bless $options, $class;
     if ($self->{persistent}) {
         $self->connect
-            or croak $self->errstr;
+            or Carp::croak $self->errstr;
     }
-
     return $self;
 }
 
@@ -188,20 +172,16 @@ sub log {
             or return undef;
     }
 
-    # If the peer is done then send() croaks
-    eval { $socket->send($message->{message}) };
-
-    if ($@) {
-        if ($self->{persistent} && $self->{reconnect}) {
+    local $SIG{PIPE} = 'IGNORE';
+    $socket->send($message->{message}) or do {
+        if ($self->{reconnect}) {
             $self->connect or return undef;
-            eval { $socket->send($message->{message}) };
-            if ($@) {
-                return $self->_raise_error("something curious happends: $@");
-            }
+            print $socket $message->{message}
+                or return $self->_raise_error("lost connection and reconnect fails: $!");
         } else {
-            return $self->_raise_error("unable to send message: $@");
+            return $self->_raise_error("unable to send message: $!");
         }
-    }
+    };
 
     if (!$self->{persistent}) {
         $self->disconnect;
@@ -217,7 +197,7 @@ sub connect {
     if (@_) {
         $opts = @_ > 1 ? {@_} : shift;
     } else {
-        $opts = $self->{sockopts};
+        $opts = $self->{sock_opts};
     }
 
     $self->{socket} = IO::Socket::INET->new(%$opts)
@@ -228,43 +208,8 @@ sub connect {
 
 sub disconnect {
     my $self = shift;
-
-    if ($self->{socket}) {
-        $self->{socket}->close;
-    }
-
-    delete $self->{socket};
-}
-
-sub validate {
-    my $self = shift;
-    my $opts = ();
-
-    eval { $opts = $self->_validate(@_) };
-
-    if ($@) {
-        return $self->_raise_error($@);
-    }
-
-    return $opts;
-}
-
-sub reload {
-    my $self = shift;
-    my $opts = $self->validate(@_);
-
-    $self->disconnect;
-
-    foreach my $key (keys %$opts) {
-        $self->{$key} = $opts->{$key};
-    }
-
-    if ($self->{persistent}) {
-        $self->connect
-            or croak $self->errstr;
-    }
-
-    return 1;
+    $self->{socket}->close;
+    $self->{socket} = undef;
 }
 
 sub errstr {
@@ -273,7 +218,6 @@ sub errstr {
 
 sub DESTROY {
     my $self = shift;
-
     if ($self->{socket}) {
         $self->{socket}->close;
     }
@@ -301,7 +245,7 @@ sub _validate {
         },
         proto => {
             type => Params::Validate::SCALAR,
-            default => "tcp",
+            default => 'tcp',
         },
         timeout => {
             type => Params::Validate::SCALAR,
@@ -329,10 +273,10 @@ sub _validate {
     });
 
     if ($options{peeraddr} && $options{peerport}) {
-        $options{sockopts}{PeerAddr} = delete $options{peeraddr};
-        $options{sockopts}{PeerPort} = delete $options{peerport};
-        $options{sockopts}{Proto}    = delete $options{proto};
-        $options{sockopts}{Timeout}  = delete $options{timeout};
+        $options{sock_opts}{PeerAddr} = delete $options{peeraddr};
+        $options{sock_opts}{PeerPort} = delete $options{peerport};
+        $options{sock_opts}{Proto}    = delete $options{proto};
+        $options{sock_opts}{Timeout}  = delete $options{timeout};
     } elsif (!$options{connect}) {
         Carp::croak "missing mandatory parameter connect or peeraddr/peerport";
     }
