@@ -27,7 +27,7 @@ Expect the config file name and returns the config as a reference.
             debug_mode = 2
             filename = example.log
             minlevel = warn
-            message_layout = %T %H[%P] [%L] %S: %m
+            prefix = '%T %H[%P] [%L] %S: '
             newline = 1
         </mylog>
     </file>
@@ -52,7 +52,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -65,7 +65,7 @@ use strict;
 use warnings;
 use Config::General;
 
-our $VERSION = '0.02';
+our $VERSION = '0.01';
 
 sub get_config {
     my ($class, $config_file) = @_;
