@@ -14,7 +14,7 @@ Log::Handler::Plugin::Config::Properties - Config loader for Config::Properties.
 
 Expect the config file name and returns the config as a reference.
 
-The configuration uses full stops "." as a delimiter.
+The configuration will be splitted by dot.
 
 =head1 CONFIG STYLE
 
@@ -28,7 +28,7 @@ The configuration uses full stops "." as a delimiter.
     file.mylog.minlevel = warn
     file.mylog.filename = example.log
     file.mylog.newline = 1
-    file.mylog.message_layout = %T %H[%P] [%L] %S: %m
+    file.mylog.prefix = '%T %H[%P] [%L] %S: '
 
 =head1 PREREQUISITES
     
@@ -50,7 +50,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2010 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -63,8 +63,7 @@ use strict;
 use warnings;
 use Config::Properties;
 
-our $VERSION = '0.04';
-our $SPLITTOTREE = qr/\./;
+our $VERSION = '0.01';
 
 sub get_config {
     my ($class, $config_file) = @_;
@@ -74,7 +73,7 @@ sub get_config {
     $properties->load($fh);
     close $fh;
 
-    my $config = $properties->splitToTree($SPLITTOTREE);
+    my $config = $properties->splitToTree(qr/\./);
     return $config;
 }
 
